Generates a diagnostic bundle of the current Relyra state.
Writes the output to ./relyra_diagnostic_bundle.zip.
mix relyra.diagnostic --repo MyApp.Repo
Generates a diagnostic bundle of the current Relyra state.
Writes the output to ./relyra_diagnostic_bundle.zip.
mix relyra.diagnostic --repo MyApp.Repo